//imports functions from D3 library
import { csv, select } from 'd3';

//imports the scatterPlot function from the scatterPlot.js file
import { scatterPlot } from './scatterPlot';

// This is the URL of my iris dataset
const csvUrl = [
  'https://gist.githubusercontent.com/',
  'prathyushajampala/', // User
  '207852177f1687c37e4c9e5a2271b641/', // Id of the Gist
  'raw/d36ca38ff1527b1e59c4d87a489f64c27da6cd73/', // commit
  'Iris_data.csv', // File name
].join('');

//  function used to parse each row of the loaded csv file
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

// To set width and height of the svg element to the size of the window
const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

//  function which loads the csv data and creates the scatter plot
const main = async () => {
  
  //invoking svg elements
  svg.call(
    
    // The scatter plot using the scatterPlot function and the csv data
    scatterPlot()
      .width(width)
      .height(height)
      .data(await csv(csvUrl, parseRow))
      .xValue((d) => d.petal_width)
      .yValue((d) => d.sepal_length)
      .symbolValue((d) => d.species)
      .margin({
        top: 20,
        right: 20,
        bottom: 40,
        left: 50,
      })
      .size(100)
  );
};
// calls the main function to start the program
main();
